@@ -51,11 +51,11 @@ def _to_gen_(iterable):
     """
     Recursively iterate lists and tuples
     """
-    from collections import Iterable
+    from collections.abc import Iterable
 
     for elm in iterable:
         if isinstance(elm, Iterable) and not isinstance(elm, (str, bytes)):
-            yield from flatten(elm)
+            yield from _to_gen_(elm)
         else: yield elm
 
 
